@@ -181,36 +181,36 @@ class RandomTransposeDialog(gtk.Dialog):
         self.m_spins['yes'] = []
         vbox.pack_start(b2)
 
-        self.m_buttons['accidentals'] = gtk.RadioButton(b1, "accidentals")
+        self.m_buttons['accidentals'] = gtk.RadioButton(b1, _("Accidentals"))
         hbox = gu.bHBox(vbox)
         hbox.pack_start(self.m_buttons['accidentals'])
         self.m_spins['accidentals'] = [
-            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1, 1), 0.0, 0),
-            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1, 1), 0.0, 0)]
+            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1), 0.0, 0)]
         hbox.pack_start(self.m_spins['accidentals'][0])
         hbox.pack_start(self.m_spins['accidentals'][1])
         gu.SpinButtonRangeController(self.m_spins['accidentals'][0],
                                      self.m_spins['accidentals'][1],
                                      -7, 7)
 
-        self.m_buttons['key'] = gtk.RadioButton(b1, "key")
+        self.m_buttons['key'] = gtk.RadioButton(b1, _("Key"))
         hbox = gu.bHBox(vbox)
         hbox.pack_start(self.m_buttons['key'])
         self.m_spins['key'] = [
-            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1, 1), 0.0, 0),
-            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1, 1), 0.0, 0)]
+            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1), 0.0, 0)]
         hbox.pack_start(self.m_spins['key'][0])
         hbox.pack_start(self.m_spins['key'][1])
         gu.SpinButtonRangeController(self.m_spins['key'][0],
                                      self.m_spins['key'][1],
                                      -10, 10)
 
-        self.m_buttons['semitones'] = gtk.RadioButton(b1, "semitones")
+        self.m_buttons['semitones'] = gtk.RadioButton(b1, _("Semitones"))
         hbox = gu.bHBox(vbox)
         hbox.pack_start(self.m_buttons['semitones'])
         self.m_spins['semitones'] = [
-            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1, 1), 0.0, 0),
-            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1, 1), 0.0, 0)]
+            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1), 0.0, 0)]
         hbox.pack_start(self.m_spins['semitones'][0])
         hbox.pack_start(self.m_spins['semitones'][1])
         gu.SpinButtonRangeController(self.m_spins['semitones'][0],
